==> ozone-1.2.0-src.tar.gz: ozone-1.2.0-src/hadoop-ozone/s3gateway/src/test/java/org/apache/hadoop/ozone/s3/TestEmptyContentTypeFilter.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.ozone.s3;

import java.util.Vector;

import org.apache.hadoop.ozone.s3.EmptyContentTypeFilter.EnumerationWrapper;

import org.junit.Assert;
import org.junit.Test;

/**
 * Tests for {@link EmptyContentTypeFilter}.
 */
public class TestEmptyContentTypeFilter {

  @Test
  public void enumerationWithContentType() {
    Vector<String> values = new Vector<>();
    values.add("Content-Type");
    values.add("1");
    values.add("2");
    values.add("Content-Type");

    final EnumerationWrapper enumerationWrapper =
        new EnumerationWrapper(values.elements());

    Assert.assertTrue(enumerationWrapper.hasMoreElements());
    Assert.assertEquals("1", enumerationWrapper.nextElement());
    Assert.assertTrue(enumerationWrapper.hasMoreElements());
    Assert.assertEquals("2", enumerationWrapper.nextElement());
    Assert.assertFalse(enumerationWrapper.hasMoreElements());
  }

  @Test
  public void enumerationWithOneContentType() {
    Vector<String> values = new Vector<>();
    values.add("Content-Type");

    final EnumerationWrapper enumerationWrapper =
        new EnumerationWrapper(values.elements());

    Assert.assertFalse(enumerationWrapper.hasMoreElements());
  }

}

==> ozone-1.4.1-src.tar.gz: ozone-1.4.1-src/hadoop-ozone/s3gateway/src/test/java/org/apache/hadoop/ozone/s3/TestEmptyContentTypeFilter.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.ozone.s3;

import java.util.Vector;

import org.apache.hadoop.ozone.s3.EmptyContentTypeFilter.EnumerationWrapper;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertTrue;

/**
 * Tests for {@link EmptyContentTypeFilter}.
 */
public class TestEmptyContentTypeFilter {

  @Test
  public void enumerationWithContentType() {
    Vector<String> values = new Vector<>();
    values.add("Content-Type");
    values.add("1");
    values.add("2");
    values.add("Content-Type");

    final EnumerationWrapper enumerationWrapper =
        new EnumerationWrapper(values.elements());

    assertTrue(enumerationWrapper.hasMoreElements());
    assertEquals("1", enumerationWrapper.nextElement());
    assertTrue(enumerationWrapper.hasMoreElements());
    assertEquals("2", enumerationWrapper.nextElement());
    assertFalse(enumerationWrapper.hasMoreElements());
  }

  @Test
  public void enumerationWithOneContentType() {
    Vector<String> values = new Vector<>();
    values.add("Content-Type");

    final EnumerationWrapper enumerationWrapper =
        new EnumerationWrapper(values.elements());

    assertFalse(enumerationWrapper.hasMoreElements());
  }

}
